@@ -1,11 +1,13 @@
-"""Implementation of the STOMP protocol in Python."""
-VERSION = (0, 1, 3)
+"""Implementation of the STOMP protocol in Python.
+
+For documentation, see: http://packages.python.org/stompy/
+"""
+VERSION = (0, 1, 4)
 __version__ = ".".join(map(str, VERSION))
 __author__ = "Benjamin W. Smith"
 __contact__ = "benjaminwarfield@just-another.net"
 __homepage__ = "http://bitbucket.org/benjaminws/python-stomp/"
 __docformat__ = "restructuredtext"
-__doc__ = "For documentation, see: packages.python.org/stompy/"
 
 
 def is_stable_release():
