@@ -220,7 +220,7 @@ class Frame(object):
         try:
             buffer = ''
             partial = ''
-            while not buffer.endswith('\x00\n'):
+            while not buffer.endswith('\x00'):
                 try:
                     partial = self.sock.recv(1)
                 except socket.error, exc:
@@ -231,7 +231,17 @@ class Frame(object):
                 buffer += partial
         finally:
             self.sock.setblocking(nb)
-        return buffer[:-2]
+
+        # ** Nasty Alert **
+        # There may be a left over newline
+        # RabbitMQ doesn't have a newline after \x00
+        # ActiveMQ does.  This is a hack around that.
+        # http://stomp.codehaus.org/Protocol mentions 
+        # nothing about a newline following the NULL (^@)
+        if buffer[:1] == '\n':
+            return buffer[1:-1]
+
+        return buffer[:-1]
 
     def __repr__(self):
         return "<Frame %s>" % pformat(self.headers)
