@@ -83,10 +83,9 @@ class Client(object):
 
         :keyword username: Username for connection
         :keyword password: Password for connection
-        :raises :exc:`stompy.stomp.ConnectionError`: if the connection
-            was unsuccessful.
-        :raises :exc:`stompy.stomp.ConnectionTimeoutError`: if the connection
-            timed out.
+
+        :raises :exc:`stompy.stomp.ConnectionError`: if the connection was unsuccessful.
+        :raises :exc:`stompy.stomp.ConnectionTimeoutError`: if the connection timed out.
 
         """
         self.stomp.connect(username=username, password=password)
